.. image:: https://github.com/rkimoakbioinformatics/oakvar/raw/master/oakvar/gui/websubmit/images/logo.png
  :width: 300
  :alt: OakVar logo

OakVar: Genomic Variant Analysis Platform
*****************************************

News
====

Greetings everyone!

I am thrilled to announce the OakVar Hackathon, an exciting opportunity to showcase your creativity and ingenuity by utilizing the power of OakVar! The challenge is to create something innovative with OakVar and submit it by April 21, 2023. The best part? The winner will receive a $100 cash prize, and all submissions will be listed in a blog post summarizing the hackathon.

The possibilities are endless - you can create anything with OakVar! Whether it's connecting OakVar to ML/AI, building a chatbot using OakVar, embedding OakVar in a web app, creating a new module for OakVar, developing an app using OakVar annotation data, or building a personal genomics app with OakVar - let your imagination run wild.

OakVar Hackathon/Competition

Submission deadline: April 30, 2023
How to submit: Host your work on GitHub
Prize: $100 cash prize for the winner

If you have any questions regarding the hackathon, please do not hesitate to ask at info@oakbioinformatics.com. We are excited to see what you will create!

Let the hackathon begin!

Mission
=======

* OakVar is a bridge between cutting-edge genomics research and everyday people.
* OakVar democratizes access to genomics knowledge for all.

What it does
============

* Annotate genomic variants with diverse annotation sources.
* Make databases of annotated variants.
* Query annotated variants with filter sets.
* Make reports in diverse formats.
* Visualize annotated variants with graphical user interface.
* Works via CLI and GUI.
* Easily develop, run, and distribute CLI and GUI genomics apps. OakVar acts as an operating system for genomics apps.
* Connect genomic data to AI/ML models.

Internship (currently full)
===========================
The main project will be OakVar. Full remote work. Unpaid position (no funding yet). Please send your application to rkim@oakbioinformatics.com.

Resources
=========
Ready to start? `OakVar Documentation`_

.. _OakVar Documentation: https://docs.oakvar.com

`Subscribe to the mailing list`_: Be in the loop and notified of the new releases and news of OakVar. 

.. _Subscribe to the mailing list: https://dashboard.mailerlite.com/forms/21170/56038572068701589/share

Medium: https://medium.com/oakvar

Discord: https://discord.gg/wZfkTMKTjG 

Reddit: https://www.reddit.com/r/oakvar

Email: rkim@oakbioinformatics.com

Many Thanks to Our Sponsors
=================================

Organizational Sponsors
-----------------------

.. image:: https://dna-seq.github.io/dna-seq/just_dna_seq.png
   :width: 225
   :alt: Just DNA-Seq
   :target: https://github.com/dna-seq

Individual Sponsors
-------------------

.. image:: https://avatars.githubusercontent.com/u/110073399?v=4
   :width: 50
   :alt: RegenCenter
   :target: https://github.com/RegenCenter

License
*******

OakVar is licensed under dual licensing: 1) APGL v3 or higher and 2) paid subscription for commercial use. For full license information, see `LICENSE`_.

.. _LICENSE: https://github.com/rkimoakbioinformatics/oakvar/blob/master/LICENSE
